==> qtjambi-debuginfo-macos-5.15.17.jar: sources/QtJambiGui/QAbstractOpenGLFunctions_shell.cpp <==
#include "QAbstractOpenGLFunctions_shell.h"
#include <QtJambi/Cast>

void deleter_QAbstractOpenGLFunctions(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QAbstractOpenGLFunctions")
    QAbstractOpenGLFunctions *_ptr = reinterpret_cast<QAbstractOpenGLFunctions *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QAbstractOpenGLFunctions_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QAbstractOpenGLFunctions_shell) ); }

jmethodID QAbstractOpenGLFunctions_shell::__shell_javaMethod(int pos) const { return QAbstractOpenGLFunctions_shell::__shell()->javaMethod(typeid(QAbstractOpenGLFunctions), pos); }

// emitting (writeShellConstructor)
// emitting (writeShellDestructor)
QAbstractOpenGLFunctions_shell::~QAbstractOpenGLFunctions_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QAbstractOpenGLFunctions::~QAbstractOpenGLFunctions()", QAbstractOpenGLFunctions_shell::__shell())
    QAbstractOpenGLFunctions_shell::__shell()->destructed(typeid(QAbstractOpenGLFunctions));
}

void QAbstractOpenGLFunctions_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QAbstractOpenGLFunctions_shell*>(ptr)->QAbstractOpenGLFunctions_shell::__shell()->tryDeleteShell(typeid(QAbstractOpenGLFunctions));
}

// emitting Virtual overrides (virtualFunctions)
bool QAbstractOpenGLFunctions_shell::initializeOpenGLFunctions()
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QAbstractOpenGLFunctions::initializeOpenGLFunctions()", QAbstractOpenGLFunctions_shell::__shell())
        if(JniEnvironment __jni_env{200}) {
            QtJambiExceptionHandler __qj_exnhandler;
            bool  __qt_return_value = false;
            QTJAMBI_TRY {
                if(jobject __java_this = QAbstractOpenGLFunctions_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jboolean __java_return_value = __jni_env->CallBooleanMethod(__java_this, method_id);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = static_cast<bool>(__java_return_value);
                } else {
                    QAbstractOpenGLFunctions_shell::__shell()->warnForMethod("QAbstractOpenGLFunctions::initializeOpenGLFunctions()");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QAbstractOpenGLFunctions::initializeOpenGLFunctions()");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QAbstractOpenGLFunctions::initializeOpenGLFunctions();
        }
    }else{
        return QAbstractOpenGLFunctions::initializeOpenGLFunctions();
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
jboolean QAbstractOpenGLFunctions_access::__qt_isInitialized(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const
{
    Q_UNUSED(__jni_env)
    Q_UNUSED(__this_nativeId)
    bool __qt_return_value = QAbstractOpenGLFunctions::isInitialized();
    return jboolean(__qt_return_value);
}

jobject QAbstractOpenGLFunctions_access::__qt_owningContext(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const
{
    Q_UNUSED(__jni_env)
    Q_UNUSED(__this_nativeId)
    QOpenGLContext* __qt_return_value = QAbstractOpenGLFunctions::owningContext();
    return qtjambi_cast<jobject>(__jni_env, __qt_return_value);
}

void QAbstractOpenGLFunctions_access::__qt_setOwningContext_const_QOpenGLContext_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID context0)
{
    Q_UNUSED(__jni_env)
    Q_UNUSED(__this_nativeId)
    const QOpenGLContext* __qt_context0 = QtJambiAPI::objectFromNativeId<QOpenGLContext>(context0);
    QAbstractOpenGLFunctions::setOwningContext(__qt_context0);
}

// emitting Virtual Override Functions (virtualOverrideFunctions)
jboolean QAbstractOpenGLFunctions_access::__qt_initializeOpenGLFunctions(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        bool __qt_return_value = QAbstractOpenGLFunctions::initializeOpenGLFunctions();
        return jboolean(__qt_return_value);
    } else {
        bool __qt_return_value = initializeOpenGLFunctions();
        return jboolean(__qt_return_value);
    }
}

// emitting (writeConstructors)
// destruct QAbstractOpenGLFunctions_shell
void __qt_destruct_QAbstractOpenGLFunctions(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QAbstractOpenGLFunctions")
    reinterpret_cast<QAbstractOpenGLFunctions_shell*>(ptr)->~QAbstractOpenGLFunctions_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QAbstractOpenGLFunctions::isInitialized()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QAbstractOpenGLFunctions_isInitialized_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QAbstractOpenGLFunctions *__qt_this = QtJambiAPI::objectFromNativeId<QAbstractOpenGLFunctions>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QAbstractOpenGLFunctions::isInitialized()const", __qt_this)
        __java_return_value = static_cast<const QAbstractOpenGLFunctions_access*>(__qt_this)->__qt_isInitialized(__jni_env, __this_nativeId);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QAbstractOpenGLFunctions::owningContext()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QAbstractOpenGLFunctions_owningContext_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QAbstractOpenGLFunctions *__qt_this = QtJambiAPI::objectFromNativeId<QAbstractOpenGLFunctions>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QAbstractOpenGLFunctions::owningContext()const", __qt_this)
        __java_return_value = static_cast<const QAbstractOpenGLFunctions_access*>(__qt_this)->__qt_owningContext(__jni_env, __this_nativeId);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QAbstractOpenGLFunctions::setOwningContext(const QOpenGLContext*)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QAbstractOpenGLFunctions_setOwningContext_1native_1const_1QOpenGLContext_1ptr__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID context0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QAbstractOpenGLFunctions *__qt_this = QtJambiAPI::objectFromNativeId<QAbstractOpenGLFunctions>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QAbstractOpenGLFunctions::setOwningContext(const QOpenGLContext*)", __qt_this)
        static_cast<QAbstractOpenGLFunctions_access*>(__qt_this)->__qt_setOwningContext_const_QOpenGLContext_ptr(__jni_env, __this_nativeId, context0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QAbstractOpenGLFunctions::initializeOpenGLFunctions()
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QAbstractOpenGLFunctions_initializeOpenGLFunctions_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QAbstractOpenGLFunctions *__qt_this = QtJambiAPI::objectFromNativeId<QAbstractOpenGLFunctions>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QAbstractOpenGLFunctions::initializeOpenGLFunctions()", __qt_this)
        __java_return_value = static_cast<QAbstractOpenGLFunctions_access*>(__qt_this)->__qt_initializeOpenGLFunctions(__jni_env, __this_nativeId);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QAbstractOpenGLFunctions(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QAbstractOpenGLFunctions>("QAbstractOpenGLFunctions", "io/qt/gui/QAbstractOpenGLFunctions");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "initializeOpenGLFunctions", "()Z")});
    registerConstructorInfos(typeId, &__qt_destruct_QAbstractOpenGLFunctions, {
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QAbstractOpenGLFunctions);
    registerSizeOfShell(typeId, sizeof(QAbstractOpenGLFunctions_shell));
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-debuginfo-macos-5.15.19.jar: sources/QtJambiGui/QAbstractOpenGLFunctions_shell.cpp <==
#include "QAbstractOpenGLFunctions_shell.h"
#include <QtJambi/Cast>

void deleter_QAbstractOpenGLFunctions(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QAbstractOpenGLFunctions")
    QAbstractOpenGLFunctions *_ptr = reinterpret_cast<QAbstractOpenGLFunctions *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QAbstractOpenGLFunctions_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QAbstractOpenGLFunctions_shell) ); }

jmethodID QAbstractOpenGLFunctions_shell::__shell_javaMethod(int pos) const { return QAbstractOpenGLFunctions_shell::__shell()->javaMethod(typeid(QAbstractOpenGLFunctions), pos); }

// emitting (writeShellConstructor)
// emitting (writeShellDestructor)
QAbstractOpenGLFunctions_shell::~QAbstractOpenGLFunctions_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QAbstractOpenGLFunctions::~QAbstractOpenGLFunctions()", QAbstractOpenGLFunctions_shell::__shell())
    QAbstractOpenGLFunctions_shell::__shell()->destructed(typeid(QAbstractOpenGLFunctions));
}

void QAbstractOpenGLFunctions_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QAbstractOpenGLFunctions_shell*>(ptr)->QAbstractOpenGLFunctions_shell::__shell()->tryDeleteShell(typeid(QAbstractOpenGLFunctions));
}

// emitting Virtual overrides (virtualFunctions)
bool QAbstractOpenGLFunctions_shell::initializeOpenGLFunctions()
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QAbstractOpenGLFunctions::initializeOpenGLFunctions()", QAbstractOpenGLFunctions_shell::__shell())
        if(JniEnvironment __jni_env{200}) {
            QtJambiExceptionHandler __qj_exnhandler;
            bool  __qt_return_value = false;
            QTJAMBI_TRY {
                if(jobject __java_this = QAbstractOpenGLFunctions_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jboolean __java_return_value = __jni_env->CallBooleanMethod(__java_this, method_id);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = static_cast<bool>(__java_return_value);
                } else {
                    QAbstractOpenGLFunctions_shell::__shell()->warnForMethod("QAbstractOpenGLFunctions::initializeOpenGLFunctions()");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QAbstractOpenGLFunctions::initializeOpenGLFunctions()");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QAbstractOpenGLFunctions::initializeOpenGLFunctions();
        }
    }else{
        return QAbstractOpenGLFunctions::initializeOpenGLFunctions();
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
jboolean QAbstractOpenGLFunctions_access::__qt_isInitialized_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const
{
    Q_UNUSED(__jni_env)
    Q_UNUSED(__this_nativeId)
    bool __qt_return_value = QAbstractOpenGLFunctions::isInitialized();
    return jboolean(__qt_return_value);
}

jobject QAbstractOpenGLFunctions_access::__qt_owningContext_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const
{
    Q_UNUSED(__jni_env)
    Q_UNUSED(__this_nativeId)
    QOpenGLContext* __qt_return_value = QAbstractOpenGLFunctions::owningContext();
    return qtjambi_cast<jobject>(__jni_env, __qt_return_value);
}

void QAbstractOpenGLFunctions_access::__qt_setOwningContext_const_QOpenGLContext_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID context0)
{
    Q_UNUSED(__jni_env)
    Q_UNUSED(__this_nativeId)
    const QOpenGLContext* __qt_context0 = QtJambiAPI::objectFromNativeId<QOpenGLContext>(context0);
    QAbstractOpenGLFunctions::setOwningContext(__qt_context0);
}

// emitting Virtual Override Functions (virtualOverrideFunctions)
jboolean QAbstractOpenGLFunctions_access::__qt_initializeOpenGLFunctions(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        bool __qt_return_value = QAbstractOpenGLFunctions::initializeOpenGLFunctions();
        return jboolean(__qt_return_value);
    } else {
        bool __qt_return_value = initializeOpenGLFunctions();
        return jboolean(__qt_return_value);
    }
}

// emitting (writeConstructors)
// destruct QAbstractOpenGLFunctions_shell
void __qt_destruct_QAbstractOpenGLFunctions(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QAbstractOpenGLFunctions")
    reinterpret_cast<QAbstractOpenGLFunctions_shell*>(ptr)->~QAbstractOpenGLFunctions_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QAbstractOpenGLFunctions::isInitialized()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QAbstractOpenGLFunctions_isInitialized_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QAbstractOpenGLFunctions *__qt_this = QtJambiAPI::objectFromNativeId<QAbstractOpenGLFunctions>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QAbstractOpenGLFunctions::isInitialized()const", __qt_this)
        __java_return_value = static_cast<const QAbstractOpenGLFunctions_access*>(__qt_this)->__qt_isInitialized_constfct(__jni_env, __this_nativeId);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QAbstractOpenGLFunctions::owningContext()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QAbstractOpenGLFunctions_owningContext_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QAbstractOpenGLFunctions *__qt_this = QtJambiAPI::objectFromNativeId<QAbstractOpenGLFunctions>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QAbstractOpenGLFunctions::owningContext()const", __qt_this)
        __java_return_value = static_cast<const QAbstractOpenGLFunctions_access*>(__qt_this)->__qt_owningContext_constfct(__jni_env, __this_nativeId);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QAbstractOpenGLFunctions::setOwningContext(const QOpenGLContext*)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QAbstractOpenGLFunctions_setOwningContext_1native_1const_1QOpenGLContext_1ptr__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID context0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QAbstractOpenGLFunctions *__qt_this = QtJambiAPI::objectFromNativeId<QAbstractOpenGLFunctions>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QAbstractOpenGLFunctions::setOwningContext(const QOpenGLContext*)", __qt_this)
        static_cast<QAbstractOpenGLFunctions_access*>(__qt_this)->__qt_setOwningContext_const_QOpenGLContext_ptr(__jni_env, __this_nativeId, context0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QAbstractOpenGLFunctions::initializeOpenGLFunctions()
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QAbstractOpenGLFunctions_initializeOpenGLFunctions_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QAbstractOpenGLFunctions *__qt_this = QtJambiAPI::objectFromNativeId<QAbstractOpenGLFunctions>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QAbstractOpenGLFunctions::initializeOpenGLFunctions()", __qt_this)
        __java_return_value = static_cast<QAbstractOpenGLFunctions_access*>(__qt_this)->__qt_initializeOpenGLFunctions(__jni_env, __this_nativeId);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QAbstractOpenGLFunctions(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QAbstractOpenGLFunctions>("QAbstractOpenGLFunctions", "io/qt/gui/QAbstractOpenGLFunctions");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "initializeOpenGLFunctions", "()Z")});
    registerConstructorInfos(typeId, &__qt_destruct_QAbstractOpenGLFunctions, {
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QAbstractOpenGLFunctions);
    registerSizeOfShell(typeId, sizeof(QAbstractOpenGLFunctions_shell));
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
